# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litematrimony/preference/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litematrimony\\Preference\\": "packages/litematrimony/preference/src",
            "Litematrimony\\Preference\\Seeders\\": "packages/litematrimony/preference/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litematrimony\Preference\Providers\PreferenceServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Preference'  => Litematrimony\Preference\Facades\Preference::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litematrimony\\Preference\\Seeders\\PreferenceTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litematrimony\Preference\Providers\PreferenceServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litematrimony\Preference\Providers\PreferenceServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litematrimony\Preference\Providers\PreferenceServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/preference/{modulename}

**User**

    http://path-to-route-folder/user/preference/{modulename}

**Public**

    http://path-to-route-folder/preferences


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/preference/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/preference/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/preference/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/preference/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/preference/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/preference/{modulename}/{slug}
    METHOD: GET