<?php

namespace Litematrimony\Preference\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use App\Http\Requests\PublicRequest;
use Litepie\Repository\Filter\RequestFilter;

use Litematrimony\Preference\Interfaces\PreferenceRepositoryInterface;
use Litematrimony\Preference\Repositories\Eloquent\Filters\PreferencePublicFilter;
use Litematrimony\Preference\Repositories\Eloquent\Presenters\PreferenceListPresenter;

class PreferencePublicController extends BaseController
{

    /**
     * Constructor.
     *
     * @return void
     */
    public function __construct(
        PreferenceRepositoryInterface $preference
    ) {
        parent::__construct();
        $this->modules = $this->modules(config('litematrimony.preference.modules'), 'preference', guard_url('preference'));
        $this->repository = $preference;
    }

    /**
     * Show preference's list.
     *
     * @return response
     */
    protected function index(PublicRequest $request)
    {

        $search = $request->search;
        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(PreferencePublicFilter::class)
            ->setPresenter(PreferenceListPresenter::class)
            ->select('preferences.*')
            ->paginate($pageLimit)
            ->withQueryString()
            ->toArray();

        extract($data);

        $categories = [];
        $tags = [];
        $recent = [];

        return $this->response->setMetaTitle(trans('preference::preference.names'))
            ->view('preference::public.preference.index')
            ->data(compact('data', 'meta', 'categories', 'tags', 'recent'))
            ->output();
    }

    /**
     * Show preference.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show(PublicRequest $request, $slug)
    {
        $data = $this->repository
            ->findBySlug($slug)
            ->toArray();

        $categories = [];
        $tags = [];
        $recent = [];
    
        return $this->response->setMetaTitle($data['title'] . trans('preference::preference.name'))
            ->view('preference::public.preference.show')
            ->data(compact('data', 'categories', 'tags', 'recent'))
            ->output();
    }

}
