<?php

namespace Litematrimony\Preference\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litematrimony\Preference\Models\Preference;

class PreferencePolicy
{

    /**
     * Determine if the given user can view the preference.
     *
     * @param UserPolicyInterface $authUser
     * @param Preference $preference
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Preference $preference)
    {
        if ($authUser->canDo('preference.preference.view') && $authUser->isAdmin()) {
            return true;
        }

        return $preference->user_id == user_id() && $preference->user_type == user_type();
    }

    /**
     * Determine if the given user can create a preference.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('preference.preference.create');
    }

    /**
     * Determine if the given user can update the given preference.
     *
     * @param UserPolicyInterface $authUser
     * @param Preference $preference
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Preference $preference)
    {
        if ($authUser->canDo('preference.preference.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $preference->user_id == user_id() && $preference->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given preference.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Preference $preference)
    {
        return $preference->user_id == user_id() && $preference->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given preference.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Preference $preference)
    {
        if ($authUser->canDo('preference.preference.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given preference.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Preference $preference)
    {
        if ($authUser->canDo('preference.preference.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
