<?php

namespace Litematrimony\Preference\Providers;

use Illuminate\Support\ServiceProvider;
use Litematrimony\Preference\Preferences;

class PreferenceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'preference');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'preference');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Litematrimony\Preference\Providers\AuthServiceProvider::class);
        $this->app->register(\Litematrimony\Preference\Providers\RouteServiceProvider::class);
        // $this->app->register(\Litematrimony\Preference\Providers\EventServiceProvider::class);
        // $this->app->register(\Litematrimony\Preference\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litematrimony.preference', function($app)
        {
            return $this->app->make(Preferences::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind Preference to repository
        $this->app->bind(
            'Litematrimony\Preference\Interfaces\PreferenceRepositoryInterface',
            \Litematrimony\Preference\Repositories\Eloquent\PreferenceRepository::class
        );
    }


    /**
     * Merges user's and preference's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litematrimony.preference'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Litematrimony\Preference\Commands\Preference::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litematrimony.preference'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litematrimony/preference.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/preference')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/preference')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
